@@ -1,7 +1,7 @@
 #
 # This file is part of Dancer-Plugin-Locale-Wolowitz
 #
-# This software is copyright (c) 2014 by Natal Ngétal.
+# This software is copyright (c) 2016 by Natal Ngétal.
 #
 # This is free software; you can redistribute it and/or modify it under
 # the same terms as the Perl 5 programming language system itself.
@@ -17,7 +17,7 @@ get '/' => sub {
 };
 
 get '/no_key' => sub {
-    my $tr = loc('hello');
+    my $tr = loc('goodbye');
     return $tr;
 };
 
@@ -28,4 +28,8 @@ get '/complex_key' => sub {
     return $tr;
 };
 
+get '/twice_same_request' => sub {
+    return loc("welcome") .' '. loc("hello");
+};
+
 1;
